@@ -20,26 +20,25 @@
 #ifndef QMLOUTPUTCOMPONENT_H
 #define QMLOUTPUTCOMPONENT_H
 
-#include <QtDeclarative/QDeclarativeComponent>
+#include <QQmlComponent>
+
+#include <kscreen/output.h>
 
 class QMLScreen;
 class QMLOutput;
-namespace KScreen {
-class Output;
-}
 
-class QMLOutputComponent : public QDeclarativeComponent
+class QMLOutputComponent : public QQmlComponent
 {
     Q_OBJECT
 
   public:
-    explicit QMLOutputComponent(QDeclarativeEngine *engine, QMLScreen *parent);
+    explicit QMLOutputComponent(QQmlEngine *engine, QMLScreen *parent);
     virtual ~QMLOutputComponent();
 
-    QMLOutput* createForOutput(KScreen::Output *output);
+    QMLOutput* createForOutput(const KScreen::OutputPtr &output);
 
   private:
-    QDeclarativeEngine *m_engine;
+    QQmlEngine *m_engine;
 
 };
 
