@@ -53,7 +53,7 @@ class Widget : public QWidget
     KScreen::ConfigPtr currentConfig() const;
 
   protected:
-    virtual bool eventFilter(QObject *object, QEvent *event);
+    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
 
   Q_SIGNALS:
     void changed();
@@ -69,7 +69,7 @@ class Widget : public QWidget
     void slotProfilesAboutToUpdate();
     void slotProfilesUpdated();
 
-    void slotIdentifyButtonClicked();
+    void slotIdentifyButtonClicked(bool checked = true);
     void slotIdentifyOutputs(KScreen::ConfigOperation *op);
     void clearOutputIdentifiers();
 
@@ -91,6 +91,7 @@ class Widget : public QWidget
     PrimaryOutputCombo *mPrimaryCombo;
     QComboBox *mProfilesCombo;
 
+    QPushButton *mScaleAllOutputsButton;
     QPushButton *mUnifyButton;
     QPushButton *mSaveProfileButton;
 
